// ---------------------------------
// Filename      : ButtonDebouncer.h
// Author        : Sven Maerivoet
// Last modified : 13/12/2017
// Target        : C++ (Arduino UNO)
//
// All rights reserved.
// ---------------------------------

/*
 Copyright 2016-2017 Sven Maerivoet
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 
   http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
*/

#ifndef BUTTONDEBOUNCER_h
#define BUTTONDEBOUNCER_h

#include "Arduino.h"

class ButtonDebouncer {
  public:
  	enum EButtonState {kIdle, kPressed, kLongPressed, kVeryLongPressed, kExtremelyLongPressed};

    // constructor
    ButtonDebouncer();

    // public methods
    void setDebounceDelay(int debounceDelay);
    void setLongPressDelay(int longPressDelay);
    void setVeryLongPressDelay(int veryLongPressDelay);
    void setExtremelyLongPressDelay(int extremelyLongPressDelay);
    void addButton(int pin);
    EButtonState checkButton(int pin);

  private:
    static const int kDefaultDebounceDelay = 50;
    static const int kDefaultLongPressDelay = 750;
    static const int kDefaultVeryLongPressDelay = 2000;
    static const int kDefaultExtremelyLongPressDelay = 5000;
    static const int kMaxNrOfButtons = 10;
    int fNrOfButtons;
    int fButtonPins[kMaxNrOfButtons];
    int fDebounceDelay;
    int fLongPressDelay;
    int fVeryLongPressDelay;
    int fExtremelyLongPressDelay;
    boolean fButtonActives[kMaxNrOfButtons];
    unsigned long fLastDebounceTimes[kMaxNrOfButtons];
};

#endif
